@@ -50,20 +50,21 @@ rhuggins91 =
                                            paste("x", 2:pvars, sep = ""))))
 
 
-  linpred.baseline = xcoeff[1]
+  lin.pred.baseline = xcoeff[1]
   if (pvars > 1)
-    linpred.baseline = linpred.baseline +
-                       Xmatrix[, 2:pvars, drop = FALSE] %*% xcoeff[2:pvars]
+    lin.pred.baseline = lin.pred.baseline +
+                        Xmatrix[, 2:pvars, drop = FALSE] %*%
+                        xcoeff[2:pvars]
   sumrowy = rep(0, length = use.n)
   for (jlocal in 1:nTimePts) {
 
     CHmatrix[, jlocal] = as.numeric(sumrowy > 0) *
                          (1 + double.ch)
 
-    linpred = linpred.baseline + (CHmatrix[, jlocal] >  0) * capeffect
+    lin.pred = lin.pred.baseline + (CHmatrix[, jlocal] >  0) * capeffect
 
     Ymatrix[, jlocal] = rbinom(use.n, size = 1,
-             prob = eta2theta(linpred, link = link, earg = earg))
+             prob = eta2theta(lin.pred, link = link, earg = earg))
 
     sumrowy = sumrowy + Ymatrix[, jlocal]
   }
@@ -393,14 +394,16 @@ dposnegbin = function(x, size, prob = NULL, munb = NULL, log = FALSE) {
   if (length(munb)) {
     if (length(prob))
       stop("'prob' and 'munb' both specified")
-    prob <- size/(size + munb)
+    prob <- size / (size + munb)
   }
-  if (!is.logical(log.arg <- log)) stop("bad input for 'log'")
+  if (!is.logical(log.arg <- log))
+    stop("bad input for 'log'")
   rm(log)
 
-  L = max(length(x), length(prob), length(size))
-  x = rep(x, len = L); prob = rep(prob, len = L);
-  size = rep(size, len = L);
+  LLL = max(length(x), length(prob), length(size))
+  x    = rep(x,    len = LLL);
+  prob = rep(prob, len = LLL);
+  size = rep(size, len = LLL);
 
   ans = dnbinom(x = x, size = size, prob = prob, log = log.arg)
   index0 = (x == 0)
@@ -420,59 +423,43 @@ dposnegbin = function(x, size, prob = NULL, munb = NULL, log = FALSE) {
 
 
 pposnegbin = function(q, size, prob = NULL, munb = NULL) {
+
   if (length(munb)) {
     if (length(prob))
       stop("'prob' and 'munb' both specified")
-    prob <- size/(size + munb)
+    prob <- size / (size + munb)
   }
   L = max(length(q), length(prob), length(size))
-  q = rep(q, len = L); prob = rep(prob, len = L); size = rep(size, len = L)
+  if (length(q)    != L)
+    q    = rep(q,    length.out = L);
+  if (length(prob) != L)
+    prob = rep(prob, length.out = L);
+  if (length(size) != L)
+    size = rep(size, length.out = L)
 
-  ifelse(q < 1, 0, (pnbinom(q,   size = size, prob = prob) -
-                    dnbinom(q*0, size = size, prob = prob))
-                  / pnbinom(q*0, size = size, prob = prob,
-                            lower.tail = FALSE))
+  ifelse(q < 1, 0,
+        (pnbinom(q, size = size, prob = prob) -
+         dnbinom(0, size = size, prob = prob))
+       / pnbinom(0, size = size, prob = prob, lower.tail = FALSE))
 }
 
 
 qposnegbin = function(p, size, prob = NULL, munb = NULL) {
-  if (length(munb)) {
-    if (length(prob))
-      stop("'prob' and 'munb' both specified")
-    prob <- size / (size + munb)
-  }
-  if (!is.Numeric(p, positive = TRUE) ||
-      any(p >= 1))
-    stop("bad input for argument 'p'")
-  qnbinom(p * pnbinom(q = p*0, size = size, prob = prob,
-                      lower.tail = FALSE) +
-              dnbinom(x = p*0, size = size, prob = prob),
-          size = size, prob = prob)
-}
 
 
-rposnegbin = function(n, size, prob = NULL, munb = NULL) {
-
-
-  use.n = if ((length.n <- length(n)) > 1) length.n else
-          if (!is.Numeric(n, integer.valued = TRUE, allowable.length = 1, positive = TRUE))
-              stop("bad input for argument 'n'") else n
-
   if (length(munb)) {
     if (length(prob))
       stop("'prob' and 'munb' both specified")
     prob <- size / (size + munb)
   }
-  ans = rnbinom(use.n, size = size, prob = prob)
-  index = (ans == 0)
-  size = rep(size, len = use.n)
-  prob = rep(prob, len = use.n)
-  while(any(index, na.rm = TRUE)) {
-    more = rnbinom(n = sum(index), size = size[index],
-                   prob = prob[index])
-    ans[index] = more
-    index = (ans == 0)
-  }
+
+  ans = qnbinom(pnbinom(q = 0, size = size, prob = prob,
+                        lower.tail = FALSE) * p +
+                dnbinom(x = 0, size = size, prob = prob),
+                size = size, prob = prob)
+  ans[p >  1] = NaN
+  ans[p <  0] = NaN
+  ans[p == 1] = Inf
   ans
 }
 
@@ -483,6 +470,7 @@ rposnegbin = function(n, size, prob = NULL, munb = NULL) {
 
 
 
+
 posnegbinomial.control <- function(save.weight = TRUE, ...)
 {
   list(save.weight = save.weight)
@@ -497,7 +485,8 @@ posnegbinomial.control <- function(save.weight = TRUE, ...)
                            shrinkage.init = 0.95, imethod = 1)
 {
 
-  if (!is.Numeric(imethod, allowable.length = 1, integer.valued = TRUE, positive = TRUE) ||
+  if (!is.Numeric(imethod, allowable.length = 1,
+                  integer.valued = TRUE, positive = TRUE) ||
      imethod > 2)
     stop("argument 'imethod' must be 1 or 2")
   if (length(isize) && !is.Numeric(isize, positive = TRUE))
@@ -516,7 +505,8 @@ posnegbinomial.control <- function(save.weight = TRUE, ...)
   if (!is.list(esize)) esize = list()
 
 
-  if (!is.Numeric(nsimEIM, allowable.length = 1, positive = TRUE, integer.valued = TRUE))
+  if (!is.Numeric(nsimEIM, allowable.length = 1,
+                  positive = TRUE, integer.valued = TRUE))
     stop("argument 'nsimEIM' must be a positive integer")
   if (nsimEIM <= 30)
     warning("argument 'nsimEIM' should be greater than 30, say")
@@ -751,35 +741,34 @@ pposgeom = function(q, prob) {
   if (!is.Numeric(prob, positive = TRUE))
     stop("bad input for argument 'prob'")
   L = max(length(q), length(prob))
-  if (length(q)    != L) q    = rep(q,    len = L);
-  if (length(prob) != L) prob = rep(prob, len = L);
-  ifelse(q < 1, 0, (pgeom(q, prob) - prob) / (1 - prob))
+  if (length(q)    != L) q    = rep(q,    length.out = L);
+  if (length(prob) != L) prob = rep(prob, length.out = L);
+  ifelse(q < 1, 0,
+        (pgeom(q, prob) -
+         dgeom(0, prob))
+       / pgeom(0, prob, lower.tail = FALSE))
 }
 
 
 qposgeom = function(p, prob) {
-  if (!is.Numeric(prob, positive = TRUE))
-    stop("bad input for argument 'prob'")
-  if (!is.Numeric(p, positive = TRUE) || any(p >= 1))
-    stop("bad input for argument 'p'")
-  qgeom(p * (1 - prob) + prob, prob = prob)
+
+
+
+
+  ans = qgeom(pgeom(0, prob, lower.tail = FALSE) * p +
+              dgeom(0, prob),
+              prob = prob)
+  ans[p >  1] = NaN
+  ans[p <  0] = NaN
+  ans[p == 1] = Inf
+  ans
 }
 
 
+
+
 rposgeom = function(n, prob) {
-  use.n = if ((length.n <- length(n)) > 1) length.n else
-          if (!is.Numeric(n, integer.valued = TRUE, allowable.length = 1, positive = TRUE))
-              stop("bad input for argument 'n'") else n
-
-  ans = rgeom(use.n, prob = prob)
-  prob = rep(prob, len = use.n)
-  index = (ans == 0)
-  while(any(index)) {
-    more = rgeom(n = sum(index), prob[index])
-    ans[index] = more
-    index = (ans == 0)
-  }
-  ans
+  qgeom(p = runif(n, min = dgeom(0, prob)), prob)
 }
 
 
@@ -788,6 +777,8 @@ rposgeom = function(n, prob) {
 
 
 
+
+
 dpospois = function(x, lambda, log = FALSE) {
   if (!is.logical(log.arg <- log)) stop("bad input for 'log'")
   rm(log)
@@ -796,6 +787,7 @@ dpospois = function(x, lambda, log = FALSE) {
     stop("bad input for argument 'lambda'")
   L = max(length(x), length(lambda))
   x = rep(x, len = L); lambda = rep(lambda, len = L); 
+
   ans = if (log.arg) {
     ifelse(x == 0, log(0.0), dpois(x, lambda, log = TRUE) -
            log1p(-exp(-lambda)))
@@ -810,36 +802,50 @@ ppospois = function(q, lambda) {
   if (!is.Numeric(lambda, positive = TRUE))
     stop("bad input for argument 'lambda'")
   L = max(length(q), length(lambda))
-  q = rep(q, len = L); lambda = rep(lambda, len = L); 
-  ifelse(q < 1, 0, (ppois(q, lambda) - exp(-lambda)) / (-expm1(-lambda)))
+  if (length(q)      != L) q      = rep(q,      length.out = L);
+  if (length(lambda) != L) lambda = rep(lambda, length.out = L);
+
+  ifelse(q < 1, 0,
+        (ppois(q, lambda) -
+         dpois(0, lambda))
+       / ppois(0, lambda, lower.tail = FALSE))
 }
 
 
 qpospois = function(p, lambda) {
-  if (!is.Numeric(lambda, positive = TRUE))
-    stop("bad input for argument 'lambda'")
-  if (!is.Numeric(p, positive = TRUE) || any(p >= 1))
-    stop("bad input for argument 'p'")
-  qpois(p * (-expm1(-lambda)) + exp(-lambda), lambda)
+
+
+  ans = qpois(ppois(0, lambda, lower.tail = FALSE) * p +
+              dpois(0, lambda),
+              lambda = lambda)
+
+  ans[p >  1] = NaN
+  ans[p <  0] = NaN
+  ans[p == 1] = Inf
+  ans
 }
 
 
-rpospois = function(n, lambda) {
-  use.n = if ((length.n <- length(n)) > 1) length.n else
-          if (!is.Numeric(n, integer.valued = TRUE, allowable.length = 1, positive = TRUE))
-              stop("bad input for argument 'n'") else n
 
-  if (any(lambda == 0))
-    stop("no zero values allowed for argument 'lambda'")
-  ans = rpois(use.n, lambda)
-  lambda = rep(lambda, len = use.n)
-  index = (ans == 0)
-  while(any(index)) {
-    more = rpois(n = sum(index), lambda[index])
-    ans[index] = more
-    index = (ans == 0)
+
+rpospois = function(n, lambda) {
+  qpois(p = runif(n, min = dpois(0, lambda)), lambda)
+}
+
+
+
+rposnegbin = function(n, size, prob = NULL, munb = NULL) {
+  if (!is.null(munb)) {
+    if (!is.null(prob))
+        stop("'prob' and 'mu' both specified")
+    qnbinom(p = runif(n,
+                      min = dnbinom(0, size,              mu = munb)),
+            size,              mu = munb)
+  } else {
+    qnbinom(p = runif(n,
+                      min = dnbinom(0, size, prob = prob           )),
+            size, prob = prob           )
   }
-  ans
 }
 
 
@@ -858,7 +864,8 @@ rpospois = function(n, lambda) {
   if (length( ilambda) && !is.Numeric(ilambda, positive = TRUE))
     stop("bad input for argument 'ilambda'")
 
-  if (!is.Numeric(imethod, allowable.length = 1, integer.valued = TRUE, positive = TRUE) ||
+  if (!is.Numeric(imethod, allowable.length = 1,
+                  integer.valued = TRUE, positive = TRUE) ||
     imethod > 3)
     stop("argument 'imethod' must be 1 or 2 or 3")
 
@@ -953,60 +960,63 @@ rpospois = function(n, lambda) {
 
 
 
-pposbinom = function(q, size, prob, lower.tail = TRUE, log.p = FALSE) {
+pposbinom = function(q, size, prob 
+                    ) {
+
+
   if (!is.Numeric(prob, positive = TRUE)) 
     stop("no zero or non-numeric values allowed for argument 'prob'")
   L = max(length(q), length(size), length(prob))
-  q = rep(q, len = L); size = rep(size, len = L); prob = rep(prob, len = L)
+  if (length(q)      != L) q      = rep(q,      length.out = L);
+  if (length(size)   != L) size   = rep(size,   length.out = L);
+  if (length(prob)   != L) prob   = rep(prob,   length.out = L);
+
   ifelse(q < 1, 0,
-        (pbinom(q = q, size = size, prob = prob, lower.tail = lower.tail,
-                log.p = log.p) - (1-prob)^size) / (1 - (1-prob)^size))
+        (pbinom(q = q, size = size, prob = prob) -
+         dbinom(x = 0, size = size, prob = prob))
+       / pbinom(q = 0, size = size, prob = prob, lower.tail = FALSE))
 }
 
 
-qposbinom = function(p, size, prob, lower.tail = TRUE, log.p = FALSE) {
-  if (!is.Numeric(prob, positive = TRUE)) 
-      stop("no zero or non-numeric values allowed for argument 'prob'")
-  if (!is.Numeric(p, positive = TRUE) || any(p >= 1))
-      stop("bad input for argument 'p'")
-  qbinom(p = p * (1 - (1-prob)^size) + (1-prob)^size, size = size,
-         prob = prob, lower.tail = lower.tail, log.p = log.p)
+qposbinom = function(p, size, prob
+                    ) {
+
+
+
+
+  ans = qbinom(pbinom(0, size, prob, lower.tail = FALSE) * p +
+               dbinom(0, size, prob),
+               size = size, prob = prob)
+
+  ans[p >  1] = NaN
+  ans[p <  0] = NaN
+  ans[p == 1] = size[p == 1]
+  ans
 }
 
 
+
 rposbinom = function(n, size, prob) {
-  use.n = if ((length.n <- length(n)) > 1) length.n else
-          if (!is.Numeric(n, integer.valued = TRUE, allowable.length = 1, positive = TRUE))
-              stop("bad input for argument 'n'") else n
-
-  if (any(prob == 0))
-    stop("no zero values allowed for argument 'prob'")
-  ans = rbinom(n = use.n, size = size, prob = prob)
-  index = (ans == 0)
-  size = rep(size, len=length(ans))
-  prob = rep(prob, len=length(ans))
-  while(any(index)) {
-    more = rbinom(n = sum(index), size[index], prob = prob[index])
-    ans[index] = more
-    index = (ans == 0)
-  }
-  ans
+  qbinom(p = runif(n, min = dbinom(0, size, prob)), size, prob)
 }
 
 
+
 dposbinom = function(x, size, prob, log = FALSE) {
   log.arg = log
   rm(log)
   L = max(length(x), length(size), length(prob))
-  x = rep(x, len = L); size = rep(size, len = L);
-                       prob = rep(prob, len = L);
+  x    = rep(x,    len = L);
+  size = rep(size, len = L);
+  prob = rep(prob, len = L);
 
   answer = NaN * x
   is0 <- (x == 0)
   ok2 <- (prob > 0) & (prob <= 1) &
          (size == round(size)) & (size > 0)
+
   answer = dbinom(x = x, size = size, prob = prob, log = TRUE) -
-           log1p(-dbinom(x = 0*x, size = size, prob = prob))
+           log1p(-dbinom(x = 0    , size = size, prob = prob))
   answer[!ok2] = NaN
   if (log.arg) {
     answer[is0 & ok2]  = log(0.0)
